@@ -1,9 +1,12 @@
 # HEADER ####################################################
-# This is file  spam/R/subset.R.                            #
-# This file is part of the spam package,                    #
-#      http://www.math.uzh.ch/furrer/software/spam/         #
+# This is file spam/R/subset.R.                             #
+# It is part of the R package spam,                         #
+#  --> https://CRAN.R-project.org/package=spam              #
+#  --> https://CRAN.R-project.org/package=spam64            #
+#  --> https://git.math.uzh.ch/reinhard.furrer/spam         #
 # by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
-#    Daniel Gerber [ctb], Kaspar Moesinger [ctb]            #
+#    Roman Flury [ctb], Daniel Gerber [ctb],                #
+#    Kaspar Moesinger [ctb]                                 #
 # HEADER END ################################################
 
 
@@ -80,7 +83,7 @@ setMethod("[",signature(x="spam",i="spam",j="missing", drop = "ANY"),
   ##               ierr=0L,
     ##               NAOK=getOption("spam.NAOK"),PACKAGE="spam") # some copying is required!!!!
     if(.format.spam(x)$package == "spam64")
-        SS <- .format64
+        SS <- .format64()
     else
         SS <- .format32
     
@@ -101,7 +104,7 @@ setMethod("[",signature(x="spam",i="spam",j="missing", drop = "ANY"),
               rowpointers = x@rowpointers,
               
               jmask = i@colindices,
-              imask = c(i@rowpointers, rep_len_long(i@rowpointers[length(i@rowpointers)], nrow+1-length(i@rowpointers))),
+              imask = c(i@rowpointers, rep_len64(i@rowpointers[length(i@rowpointers)], nrow+1-length(i@rowpointers))),
               
               c = x@entries,
               jc = x@colindices,
