@@ -1,3 +1,14 @@
+# HEADER ####################################################
+# This is file spam/tests/testthat/test-profile.R.          #
+# It is part of the R package spam,                         #
+#  --> https://CRAN.R-project.org/package=spam              #
+#  --> https://CRAN.R-project.org/package=spam64            #
+#  --> https://git.math.uzh.ch/reinhard.furrer/spam         #
+# by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
+#    Roman Flury [ctb], Daniel Gerber [ctb],                #
+#    Kaspar Moesinger [ctb]                                 #
+# HEADER END ################################################
+
 rm(list = ls())
 source("helper.R")
 
@@ -32,7 +43,8 @@ test_that(".format.spam()",{
 })
 
 
-test_that(".validate_spam()",{
+## to be added
+## test_that(".validate_spam()",{
 
 
-})
+## })
